package xhttp3.internal.http;

import java.util.List;
import xhttp3.Cookie;
import xhttp3.CookieJar;
import xhttp3.Headers;
import xhttp3.HttpUrl;
import xhttp3.Interceptor;
import xhttp3.MediaType;
import xhttp3.Request;
import xhttp3.RequestBody;
import xhttp3.Response;
import xhttp3.internal.Util;
import xhttp3.internal.Version;
import xio.GzipSource;
import xio.Okio;

public final class BridgeInterceptor implements Interceptor {
   private final CookieJar cookieJar;

   public BridgeInterceptor(CookieJar cookieJar) {
      this.cookieJar = cookieJar;
   }

   private String cookieHeader(List<Cookie> cookies) {
      StringBuilder var5;
      var5 = new StringBuilder.<init>();
      int var2 = 0;

      for(int var3 = cookies.size(); var2 < var3; ++var2) {
         if (var2 > 0) {
            var5.append("; ");
         }

         Cookie var4;
         var5.append((var4 = (Cookie)cookies.get(var2)).name()).append('=').append(var4.value());
      }

      return var5.toString();
   }

   public Response intercept(Interceptor.Chain chain) {
      Request var2;
      Request var10000 = var2 = chain.request();
      Request.Builder var3 = var10000.newBuilder();
      RequestBody var4;
      if ((var4 = var10000.body()) != null) {
         MediaType var5;
         if ((var5 = var4.contentType()) != null) {
            var3.header("Content-Type", var5.toString());
         }

         long var11;
         if ((var11 = var4.contentLength()) != -1L) {
            var3.header("Content-Length", Long.toString(var11));
            var3.removeHeader("Transfer-Encoding");
         } else {
            var3.header("Transfer-Encoding", "chunked");
            var3.removeHeader("Content-Length");
         }
      }

      if (var2.header("Host") == null) {
         var3.header("Host", Util.hostHeader(var2.url(), false));
      }

      if (var2.header("Connection") == null) {
         var3.header("Connection", "Keep-Alive");
      }

      boolean var12 = false;
      if (var2.header("Accept-Encoding") == null) {
         var12 = true;
         var3.header("Accept-Encoding", "gzip");
      }

      List var13;
      if (!(var13 = this.cookieJar.loadForRequest(var2.url())).isEmpty()) {
         var3.header("Cookie", this.cookieHeader(var13));
      }

      if (var2.header("User-Agent") == null) {
         var3.header("User-Agent", Version.userAgent());
      }

      Response chain1;
      Response var10001 = chain1 = chain.proceed(var3.build());
      CookieJar var10002 = this.cookieJar;
      HttpUrl var6 = var2.url();
      HttpHeaders.receiveHeaders(var10002, var6, chain1.headers());
      Response.Builder var7 = var10001.newBuilder().request(var2);
      if (var12 && "gzip".equalsIgnoreCase(chain1.header("Content-Encoding")) && HttpHeaders.hasBody(chain1)) {
         GzipSource var10;
         var10 = new GzipSource.<init>(chain1.body().source());
         Headers chain2;
         var7.headers(chain2 = chain1.headers().newBuilder().removeAll("Content-Encoding").removeAll("Content-Length").build());
         var7.body(new RealResponseBody(chain2, Okio.buffer(var10)));
      }

      return var7.build();
   }
}
